<div class="modal fade" id="GM" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                <h4 class="modal-title" id="ModalLabel">上传apk包</h4>
            </div>
            <div class="modal-body">
                <div class="panel-content">
                    <div class="row">
                        <form action="{{ URL::action('ApkController@getApkAdd',[]) }}" method="post" id="form-apk" enctype="multipart/form-data">
                            <div class="form-group col-lg-6" id="update_game">
                                <h6>游戏名称</h6>
                                <input type="text" class="form-control" name="name" id="game_name" placeholder="游戏名称"/>
                            </div>
                        <div class="form-group col-lg-6" id="update_game">
                            <h6>apk包版本</h6>
                            <input type="text" class="form-control" name="version" id="version" placeholder="apk包版本"/>
                        </div>

                        <div class="form-group  col-lg-6">
                            <h6>备注</h6>
                            <input type="text" class="form-control" name="remark" id="remark"  placeholder="备注">
                        </div>

                        <div class="form-group col-lg-12">
                            <div class="form-group " id="aetherupload-wrapper" >
                                <h6>apk包</h6>
                                <div class="container">
                                    <div class="row">
                                            <div class="form-group " id="aetherupload-wrapper" >
                                                <div class="controls" >
                                                    <input type="file" id="file" onchange="aetherupload(this,'file').success(someCallback).upload()"/>
                                                    <div class="progress " style="height: 6px;margin-bottom: 2px;margin-top: 10px;width: 200px;">
                                                        <div id="progressbar" style="background:blue;height:6px;width:0;"></div>
                                                    </div>
                                                    <span style="font-size:12px;color:#aaa;" id="output"></span>
                                                    <input type="hidden" name="apk" id="savedpath" value=""/>
                                                    <input type="hidden" name="apk_origin_name" id="apk_origin_name" value=""/>
                                                    <input type="hidden" name="apk_size" id="apk_size" value=""/>
                                                </div>
                                            </div>
                                        <div id="result" class="form-group col-lg-6"></div>
                                    </div>
                                </div>
                                <script src="/js/spark-md5.min.js"></script>
                                <script src="/js/jquery.min.js"></script>
                                <script src="/js/aetherupload.js"></script>
                                <script>
                                    someCallback = function(){
                                        $('#result').append(
                                            '<p>文件原名：<span >'+this.fileName+'</span> | 文件大小：<span >'+parseFloat(this.fileSize / (1000 * 1000)).toFixed(2) + 'MB'+'</span></p>'
                                        );
                                    }

                                </script>
                            </div>
                        </div>
                        <div class="col-lg-12" style="margin-top:8px;">
                            <span style="color:red;display: none;"  id="error_info">*上传apk包</span>
                        </div>
                        <input type="hidden" id="_token" name="_token" value="{{ csrf_token() }}">
                        <div class="modal-footer col-lg-12">
                            <button type="button" class="btn btn-primary" id="btn_confirm" onclick="checkConfirm()" >确认</button>
                            <button type="button" class="btn btn-default" id="btn_close" onclick="checkClose('GM')">关闭</button>
                        </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>



<div class="modal fade" id="check-box" tabindex="-1" role="dialog" aria-labelledby="modal-error-label">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header state modal-danger">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                <h4 class="modal-title" id="modal-error-label"><i class="fa fa-warning"></i>确认框</h4>
            </div>
            <div class="modal-body" id="modal-info">
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-danger" onclick="statusConfirm()">确认</button>
                <button type="button" class="btn btn-default" onclick="checkClose('check-box')">关闭</button>
            </div>
        </div>
    </div>
</div>


<div class="modal fade" id="change-status" tabindex="-1" role="dialog" aria-labelledby="modal-error-label">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header state modal-danger">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                <h4 class="modal-title" id="modal-error-label"><i class="fa fa-warning"></i>确认框</h4>
            </div>
            <div class="modal-body" id="change_info"></div>
            <div class="modal-footer">
                <button type="button" class="btn btn-danger" onclick="return save_status();" id="change_status">确认</button>
                <button type="button" class="btn btn-default" onclick="return checkClose('change-status');" id="cancel_change_status">取消</button>
            </div>
        </div>
    </div>
</div>


<div class="modal fade" id="GMUP" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                <h4 class="modal-title" id="ModalLabel">修改apk包</h4>
            </div>
            <div class="modal-body">
                <div class="panel-content">
                    <div class="row">
                        <form action="{{ URL::action('ApkController@getApkEdit',[]) }}" method="post" id="form-apk-up" enctype="multipart/form-data">
                            <div class="form-group col-lg-6" id="update_game">
                                <h6>游戏名称</h6>
                                <input type="text" class="form-control" name="name" id="up_game_name" placeholder="游戏名称"/>
                            </div>
                            <div class="form-group col-lg-6" id="update_game">
                                <h6>apk包版本</h6>
                                <input type="text" class="form-control" name="version" id="up_version" placeholder="apk包版本"/>
                            </div>

                            <div class="form-group  col-lg-6">
                                <h6>备注</h6>
                                <input type="text" class="form-control" name="remark" id="up_remark"  placeholder="备注">
                            </div>
                            <div class="col-lg-12" style="margin-top:8px;">
                                <span style="color:red;display: none;"  id="error_info">*</span>
                            </div>
                            <input type="hidden" id="_token" name="_token" value="{{ csrf_token() }}">
                            <input type="hidden" id="up_id" name="up_id" value="">
                            <div class="modal-footer col-lg-12">
                                <button type="button" class="btn btn-primary" id="btn_confirm" onclick="checkConfirmUp()" >确认</button>
                                <button type="button" class="btn btn-default" id="btn_close" onclick="checkClose('GMUP')">关闭</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
